==> tine20-sales_2018.08.9.tar.bz2: Sales/js/Sales-lang-tr_TR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Sales **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Turkish (Turkey) (http://www.transifex.com/tine20/tine20/language/tr_TR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: tr_TR\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "CLEARED"
: ""

, "INVOICE"
: ""

, "Invoice Timesheet"
: ""

, "Customer, Customers"
: [
  ""
 ,""

]
, "Core Data"
: ""

, "Accounting"
: ""

, "Miscellaneous"
: ""

, "Customer Number"
: ""

, "Name"
: ""

, "Name shorthand"
: ""

, "Web"
: ""

, "Description"
: ""

, "Contact Person (external)"
: ""

, "Contact Person (internal)"
: ""

, "VAT No."
: ""

, "Credit Term (days)"
: ""

, "Currency"
: ""

, "Currency Translation Rate"
: ""

, "Discount (%)"
: ""

, "Delivery Addresses"
: ""

, "Billing Addresses"
: ""

, "Prefix"
: ""

, "Additional Prefix"
: ""

, "Street"
: ""

, "Postalcode"
: ""

, "Locality"
: ""

, "Region"
: ""

, "Country"
: ""

, "Postbox"
: ""

, "Invoice Position, Invoice Positions"
: [
  ""
 ,""

]
, "Type"
: ""

, "Title"
: ""

, "Month"
: ""

, "Unit"
: ""

, "Quantity"
: ""

, "Offer, Offers"
: [
  ""
 ,""

]
, "Order Confirmation, Order Confirmations"
: [
  ""
 ,""

]
, "Number"
: ""

, "Product, Products"
: [
  ""
 ,""

]
, "Contract, Contracts"
: [
  ""
 ,""

]
, "Billing Interval"
: ""

, "Billing Point"
: ""

, "Start Date"
: ""

, "End Date"
: ""

, "Invoice Item"
: ""

, "Piece"
: ""

, "Purchaseprice"
: ""

, "Salesprice"
: ""

, "Category"
: ""

, "Manufacturer"
: ""

, "Accountable"
: ""

, "GTIN"
: ""

, "Lifespan start"
: ""

, "Lifespan end"
: ""

, "Is active"
: ""

, "Invoice, Invoices"
: [
  ""
 ,""

]
, "Invoice Number"
: ""

, "Address, Addresss"
: [
  ""
 ,""

]
, "Date"
: ""

, "Interval Begins"
: ""

, "Interval Ends"
: ""

, "Credit Term"
: ""

, "Cost Center, Cost Centers"
: [
  ""
 ,""

]
, "Cleared"
: ""

, "Price Net"
: ""

, "Price Tax"
: ""

, "Price Gross"
: ""

, "Sales Tax"
: ""

, "Inventory Change"
: ""

, "Positions"
: ""

, "Reversal Invoice"
: ""

, "Supplier, Suppliers"
: [
  ""
 ,""

]
, "Supplier Number"
: ""

, "Division, Divisions"
: [
  ""
 ,""

]
, "Number Debit"
: ""

, "Products"
: ""

, "Billing Address"
: ""

, "Lead Cost Center"
: ""

, "Merge"
: ""

, "Responsible"
: ""

, "Partner"
: ""

, "Time Account"
: ""

, "Remark"
: ""

, "Purchase Invoice, Purchase Invoices"
: [
  ""
 ,""

]
, "Approver"
: ""

, "Date of invoice"
: ""

, "Due in"
: ""

, "Due at"
: ""

, "Payed at"
: ""

, "Payment_method"
: ""

, "Discount until"
: ""

, "Additional Price Gross"
: ""

, "Total Price"
: ""

, "without customer"
: ""

, "Export Records from these Positions"
: ""

, "Either postalcode or postbox is required!"
: ""

, "Copy Supplier"
: ""

, "Add New Supplier"
: ""

, "Edit Supplier \"{0}\""
: ""

, "Copy address to the clipboard"
: ""

, "IBAN"
: ""

, "BIC"
: ""

, "Postal Address"
: ""

, "Enter description"
: ""

, "Cancel"
: ""

, "Ok"
: ""

, "Select customer"
: ""

, "Bill Contract"
: ""

, "Billing Contract..."
: ""

, "Bill Contract \"{0} - {1}\""
: ""

, "Select the date to generate the bill for"
: ""

, "total"
: ""

, "inclusive"
: ""

, "exceeding"
: ""

, "Create timesheet"
: ""

, "Create Reversal Invoice"
: ""

, "Copy Invoice"
: ""

, "Add New Invoice"
: ""

, "Edit Invoice \"{0}\""
: ""

, "Positions ({0})"
: ""

, "No customer assigned"
: ""

, "The selected contract doesn't have a customer assigned, yet. Add a customer to the contract with the contract edit dialog."
: ""

, "No cost center assigned"
: ""

, "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
: ""

, "Sales Tax (percent)"
: ""

, "automatically set..."
: ""

, "OK"
: ""

, "Loading..."
: ""

, "Euro (€)"
: ""

, "Set as accountable"
: ""

, "Choose product for accountable"
: ""

, "Please use a decimal number here!"
: ""

, "Enter description..."
: ""

, "Add New Product"
: ""

, "Product Number"
: ""

, "Select supplier"
: ""

, "Add New Cost Center"
: ""

, "Select invoice"
: ""

, "Either street or postbox is required!"
: ""

, "Only numbers are allowed!"
: ""

, "Copy Customer"
: ""

, "Add New Customer"
: ""

, "Edit Customer \"{0}\""
: ""

, "without external contact person"
: ""

, "without approver"
: ""

, "without supplier"
: ""

, "Copy Purchase Invoice"
: ""

, "Add New Purchase Invoice"
: ""

, "Edit Purchase Invoice \"{0}\""
: ""

, "Due date"
: ""

, "Overdue date"
: ""

, "Dun date"
: ""

, "Method of payment"
: ""

, "without internal contact person"
: ""

, "Delivery Address"
: ""

, "Edit {0} \"{1}\""
: ""

, "Add new Billing Address"
: ""

, "Add new Delivery Address"
: ""

, "Apply postal address"
: ""

, "Add New Offer"
: ""

, "Add New Order Confirmation"
: ""

, "Interval"
: ""

, "begin"
: ""

, "end"
: ""

, "Last Autobill"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Edit Attributes"
: ""

, "Attribute"
: ""

, "Value"
: ""

, "Add a New Value..."
: ""

, "Clipboard"
: ""

, "Add New Division"
: ""

, "without contract"
: ""

, "without order confirmation"
: ""

, "Rebilling Invoice..."
: ""

, "Rebill Invoice"
: ""

, "Merge Invoices"
: ""

, "without Cost Center"
: ""

, "Auto Invoice Contract Interval"
: ""

, "Sets the biggest interval, contracts will be billed."
: ""

, "Ignore Billables Before Date"
: ""

, "Sets the date billables will be ignored before."
: ""

, "Contract Number Creation"
: ""

, "Should the contract number be set manually or be auto-created?"
: ""

, "automatically"
: ""

, "manually"
: ""

, "Contract Number Validation"
: ""

, "The Number can be validated as text or number."
: ""

, "Text"
: ""

, "Own Currency"
: ""

, "The currency defined here is used as default currency in the customerd edit dialog."
: ""

, "Invoice Type"
: ""

, "Possible Invoice Types."
: ""

, "Reversal"
: ""

, "Credit"
: ""

, "Product Category"
: ""

, "Possible Product Categories."
: ""

, "Default"
: ""

, "Product Number Creation"
: ""

, "Should the product number be set manually or be auto-created?"
: ""

, "Product Number Validation"
: ""

, "Product Number Prefix"
: ""

, "The prefix of the product number."
: ""

, "Product Number Zero Fill"
: ""

, "Fill the number with leading zero"
: ""

, "Payment Method"
: ""

, "Possible Payment Methods."
: ""

, "Bank transfer"
: ""

, "Direct debit"
: ""

, "Cancellation"
: ""

, "Credit card"
: ""

, "EC card"
: ""

, "Paypal"
: ""

, "Invoice Cleared"
: ""

, "Possible Invoice Cleared States."
: ""

, "to clear"
: ""

, "cleared"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Sales Application."
: ""

, "Invoices Module"
: ""

, "Offers Module"
: ""

, "Order Confirmations Module"
: ""

, "Suppliers Module"
: ""

, "Purchase Invoice Module"
: ""

, "manage products"
: ""

, "add, edit and delete products"
: ""

, "manage contracts"
: ""

, "add, edit and delete contracts"
: ""

, "manage cost centers"
: ""

, "add, edit and delete cost centers"
: ""

, "manage customers"
: ""

, "add, edit and delete customers"
: ""

, "manage suppliers"
: ""

, "add, edit and delete suppliers"
: ""

, "manage invoices"
: ""

, "add, edit and delete invoices"
: ""

, "manage divisions"
: ""

, "add, edit and delete divisions"
: ""

, "manage order confirmations"
: ""

, "add, edit and delete order confirmations"
: ""

, "manage offers"
: ""

, "add, edit and delete offers"
: ""

, "manage purchase invoices"
: ""

, "add, edit and delete purchase invoices"
: ""

, "change number of an order confirmations"
: ""

, "allow to change the number of an order confirmation on update"
: ""

, "set number of invoices"
: ""

, "allow to set the number of an invoice"
: ""

, "No Right to alter the Number"
: ""

, "You are not allowed to alter the number afterwards!"
: ""

, "Address as Billing Address in Use"
: ""

, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
: ""

, "Number duplicate"
: ""

, "The number you tried to use has been taken already. Please use another one leave the field blank to take the next free number."
: ""

, "Following Invoices Found"
: ""

, "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
: ""

, "Invoice is cleared already"
: ""

, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
: ""

, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
: ""

, "Unknown Currency Code"
: ""

, "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
: ""

, "You do not have admin rights on Sales"
: ""

, "The number you have tried to set is already in use!"
: ""

, "My Products"
: ""

, "Products created by me"
: ""

, "My Contracts"
: ""

, "Contracts created by myself"
: ""

, "All Customers"
: ""

, "All customer records"
: ""

, "All Offers"
: ""

, "All offer records"
: ""

, "Inactive Contracts"
: ""

, "Contracts that have already been terminated"
: ""

, "Active Contracts"
: ""

, "Contracts that are still running"
: ""

, "Products created by myself"
: ""

, "Status"
: ""

, "Cleared In"
: ""

, "All Suppliers"
: ""

, "All supllier records"
: ""

, "All Purchase Imvoices"
: ""

, "All purchase invoices"
: ""

, "All Products"
: ""

, "All product records"
: ""

, "All Contracts"
: ""

, "All contract records"
: ""

, "All Invoices"
: ""

, "All invoice records"
: ""

, "All Cost Centers"
: ""

, "All costcenter records"
: ""

, "All Divisions"
: ""

, "All division records"
: ""

, "All Order Confirmations"
: ""

, "All order confirmation records"
: ""

, "Customer"
: ""

, "Invoice Position"
: ""

, "Offer"
: ""

, "Order Confirmation"
: ""

, "Product"
: ""

, "Contract"
: ""

, "Invoice"
: ""

, "Address"
: ""

, "Cost Center"
: ""

, "Supplier"
: ""

, "Division"
: ""

, "Purchase Invoice"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-sales_2022.11.3.tar.bz2: Sales/js/Sales-lang-tr_TR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Sales **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:58+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Turkish (Turkey) (http://www.transifex.com/tine20/tine20/language/tr_TR/)\nLanguage: tr_TR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Invoice is cleared already"
: ""

, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
: ""

, "Address as Billing Address in Use"
: ""

, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
: ""

, "Following Invoices Found"
: ""

, "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
: ""

, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
: ""

, "No Right to alter the Number"
: ""

, "You are not allowed to alter the number afterwards!"
: ""

, "Number duplicate"
: ""

, "The number you tried to use has been taken already. Please use another one leave the field blank to take the next free number."
: ""

, "Unknown Currency Code"
: ""

, "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
: ""

, "Manage Products"
: ""

, "Add, edit and delete products."
: ""

, "Manage Contracts"
: ""

, "Add, edit and delete contracts."
: ""

, "Manage Cost Centers"
: ""

, "Add, edit and delete cost centers."
: ""

, "Manage Customers"
: ""

, "Add, edit and delete customers."
: ""

, "Manage Suppliers"
: ""

, "Add, edit and delete suppliers."
: ""

, "manage invoices"
: ""

, "Add, edit and delete invoices."
: ""

, "Manage Order Confirmations"
: ""

, "Add, edit and delete order confirmations."
: ""

, "Manage Offers"
: ""

, "Add, edit and delete offers."
: ""

, "Manage Purchase Invoices"
: ""

, "Add, edit and delete purchase invoices."
: ""

, "Change number of an order confirmations"
: ""

, "Allow changing the number of an order confirmation during the update."
: ""

, "Set number of invoices"
: ""

, "Allow to set the number of an invoice."
: ""

, "CSV all data"
: ""

, "Invoice Timesheet"
: ""

, "CLEARED"
: ""

, "INVOICE"
: ""

, "You do not have admin rights on Sales"
: ""

, "Boilerplate, Boilerplates"
: [
  ""
 ,""

]
, "The number you have tried to set is already in use!"
: ""

, "You have to set a customer!"
: ""

, "GENDER_Customer"
: ""

, "Customer, Customers"
: [
  ""
 ,""

]
, "Customer Number"
: ""

, "Name"
: ""

, "Name shorthand"
: ""

, "Web"
: ""

, "Description"
: ""

, "Contact Person (external)"
: ""

, "Contact Person (internal)"
: ""

, "VAT ID"
: ""

, "Credit Term (days)"
: ""

, "Currency"
: ""

, "Currency Translation Rate"
: ""

, "Discount (%)"
: ""

, "Delivery Addresses"
: ""

, "Billing Addresses"
: ""

, "GENDER_Supplier"
: ""

, "Supplier, Suppliers"
: [
  ""
 ,""

]
, "Supplier Number"
: ""

, "Prefix"
: ""

, "Additional Prefix"
: ""

, "Street"
: ""

, "Postalcode"
: ""

, "Locality"
: ""

, "Region"
: ""

, "Country"
: ""

, "Postbox"
: ""

, "GENDER_Contract"
: ""

, "Contract, Contracts"
: [
  ""
 ,""

]
, "Products"
: ""

, "Number"
: ""

, "Title"
: ""

, "Billing Address"
: ""

, "Start Date"
: ""

, "End Date"
: ""

, "Lead Cost Center"
: ""

, "Merge"
: ""

, "Responsible"
: ""

, "Partner"
: ""

, "Time Account"
: ""

, "GENDER_Offer"
: ""

, "Offer, Offers"
: [
  ""
 ,""

]
, "Order Confirmation, Order Confirmations"
: [
  ""
 ,""

]
, "Position, Positions"
: [
  ""
 ,""

]
, "GENDER_Position"
: ""

, "Type"
: ""

, "Pos."
: ""

, "Product, Products"
: [
  ""
 ,""

]
, "Grouping"
: ""

, "Sorting"
: ""

, "Product / Service"
: ""

, "Quantity"
: ""

, "Use Actual Quantity"
: ""

, "Unit"
: ""

, "Unit Price"
: ""

, "Price"
: ""

, "Position Discount Type"
: ""

, "Position Discount Percentage"
: ""

, "Position Discount Sum"
: ""

, "Net price"
: ""

, "Sales Tax Rate"
: ""

, "Sales Tax"
: ""

, "Gross Price"
: ""

, "Cost Bearer"
: ""

, "Costcenter"
: ""

, "GENDER_Invoice"
: ""

, "Invoice, Invoices"
: [
  ""
 ,""

]
, "Invoice Number"
: ""

, "Address, Addresss"
: [
  ""
 ,""

]
, "Date"
: ""

, "Interval Begins"
: ""

, "Interval Ends"
: ""

, "Credit Term"
: ""

, "Cost Center"
: ""

, "Cleared"
: ""

, "Price Net"
: ""

, "Taxes (VAT)"
: ""

, "Price Gross"
: ""

, "Inventory Change"
: ""

, "Positions"
: ""

, "Reversal Invoice"
: ""

, "Invoice Item"
: ""

, "GENDER_Address"
: ""

, "Language"
: ""

, "Email"
: ""

, "Prefix 1"
: ""

, "Prefix 2"
: ""

, "Prefix 3"
: ""

, "Number Debit"
: ""

, "Billing Interval"
: ""

, "Billing Point"
: ""

, "Piece"
: ""

, "Model"
: ""

, "From"
: ""

, "Until"
: ""

, "Document Category"
: ""

, "GENDER_Subproduct"
: ""

, "Subproduct, Subproducts"
: [
  ""
 ,""

]
, "Shortcut"
: ""

, "Variable Position Flag"
: ""

, "Amount"
: ""

, "GENDER_Order Confirmation"
: ""

, "Purchase Invoice, Purchase Invoices"
: [
  ""
 ,""

]
, "Approver"
: ""

, "Date of invoice"
: ""

, "Due in"
: ""

, "Due at"
: ""

, "Payed at"
: ""

, "Payment Method"
: ""

, "Discount until"
: ""

, "Additional Price Gross"
: ""

, "Total Price"
: ""

, "Category"
: ""

, "GTIN"
: ""

, "Default Grouping"
: ""

, "Default Sorting"
: ""

, "Purchaseprice"
: ""

, "Salesprice"
: ""

, "Manufacturer"
: ""

, "Subproducts"
: ""

, "Is Sales Product"
: ""

, "Is active"
: ""

, "Accountable"
: ""

, "Lifespan start"
: ""

, "Lifespan end"
: ""

, "GENDER_Order"
: ""

, "Order, Orders"
: [
  ""
 ,""

]
, "Status"
: ""

, "Invoice Recipient"
: ""

, "Delivery Recipient"
: ""

, "OR-"
: ""

, "OF-"
: ""

, "Document, Documents"
: [
  ""
 ,""

]
, "GENDER_Document"
: ""

, "Document Number"
: ""

, "Boilerplates"
: ""

, "Document Date"
: ""

, "Customer Reference"
: ""

, "Recipient"
: ""

, "Reference Person"
: ""

, "Positions Net Sum"
: ""

, "Positions Discount Sum"
: ""

, "Invoice Discount Type"
: ""

, "Invoice Discount Percentage"
: ""

, "Invoice Discount Sum"
: ""

, "Net Sum"
: ""

, "Sales Tax by Rate"
: ""

, "Gross Sum"
: ""

, "Internal Note"
: ""

, "Proforma Number"
: ""

, "PI-"
: ""

, "IN-"
: ""

, "GENDER_Delivery"
: ""

, "Delivery, Deliveries"
: [
  ""
 ,""

]
, "PD-"
: ""

, "DN-"
: ""

, "Invoice Position, Invoice Positions"
: [
  ""
 ,""

]
, "Month"
: ""

, "My Products"
: ""

, "Products created by me"
: ""

, "My Contracts"
: ""

, "Contracts created by myself"
: ""

, "All Customers"
: ""

, "All customer records"
: ""

, "All Offers"
: ""

, "All offer records"
: ""

, "Inactive Contracts"
: ""

, "Contracts that have already been terminated"
: ""

, "Active Contracts"
: ""

, "Contracts that are still running"
: ""

, "All Suppliers"
: ""

, "All supllier records"
: ""

, "All Purchase Imvoices"
: ""

, "All purchase invoices"
: ""

, "All Products"
: ""

, "All product records"
: ""

, "All Contracts"
: ""

, "All contract records"
: ""

, "All Invoices"
: ""

, "All invoice records"
: ""

, "All Order Confirmations"
: ""

, "All order confirmation records"
: ""

, "Auto Invoice Contract Interval"
: ""

, "Sets the biggest interval, contracts will be billed."
: ""

, "Offer Status"
: ""

, "Possible Offer Status"
: ""

, "Draft (unbooked, open)"
: ""

, "Released (booked, open)"
: ""

, "Ordered (booked, closed)"
: ""

, "Rejected (booked, closed)"
: ""

, "Offer Status Transitions"
: ""

, "Possible Offer Status Transitions"
: ""

, "Order Status"
: ""

, "Possible Order Status"
: ""

, "Received (unbooked, open)"
: ""

, "Accepted (booked, open)"
: ""

, "Done (booked, closed)"
: ""

, "Order Status Transitions"
: ""

, "Possible Order Status Transitions"
: ""

, "Delivery Status"
: ""

, "Possible Delivery Status"
: ""

, "Created (unbooked, open)"
: ""

, "Delivery Status Transitions"
: ""

, "Possible Delivery Status Transitions"
: ""

, "Invoice Status"
: ""

, "Possible Invoice Status"
: ""

, "Proforma (unbooked, open)"
: ""

, "Booked (booked, open)"
: ""

, "Shipped (booked, closed)"
: ""

, "Paid (booked, closed)"
: ""

, "Invoice Status Transitions"
: ""

, "Possible Invoice Status Transitions"
: ""

, "Ignore Billables Before Date"
: ""

, "Sets the date billables will be ignored before."
: ""

, "Contract Number Creation"
: ""

, "Should the contract number be set manually or be auto-created?"
: ""

, "automatically"
: ""

, "manually"
: ""

, "Contract Number Validation"
: ""

, "The Number can be validated as text or number."
: ""

, "Text"
: ""

, "Own Currency"
: ""

, "The currency defined here is used as default currency in the customerd edit dialog."
: ""

, "Languages Available"
: ""

, "List of languages available in the sales modules."
: ""

, "Invoice Type"
: ""

, "Possible Invoice Types."
: ""

, "Reversal"
: ""

, "Credit"
: ""

, "Percentage"
: ""

, "Sum"
: ""

, "Document Position Type"
: ""

, "Heading"
: ""

, "Page Break"
: ""

, "Alternative"
: ""

, "Optional"
: ""

, "Standard"
: ""

, "Product Category"
: ""

, "Possible Product Categories."
: ""

, "Default"
: ""

, "Product Unfold Type"
: ""

, "Shared"
: ""

, "Own"
: ""

, "Product Unit"
: ""

, "Sub-Product Variable Position Flag"
: ""

, "Accounting for the sub-product is variable and each same sub-product gets on own or a common shared position in a document."
: ""

, "None"
: ""

, "Product Number Creation"
: ""

, "Should the product number be set manually or be auto-created?"
: ""

, "Product Number Validation"
: ""

, "Product Number Prefix"
: ""

, "The prefix of the product number."
: ""

, "Product Number Zero Fill"
: ""

, "Fill the number with leading zero"
: ""

, "Possible Payment Methods."
: ""

, "Bank transfer"
: ""

, "Direct debit"
: ""

, "Cancellation"
: ""

, "Credit card"
: ""

, "EC card"
: ""

, "Paypal"
: ""

, "Assets"
: ""

, "Invoice Cleared"
: ""

, "Possible Invoice Cleared States."
: ""

, "to clear"
: ""

, "cleared"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Sales Application."
: ""

, "Invoices Module"
: ""

, "Offers Module"
: ""

, "Order Confirmations Module"
: ""

, "Suppliers Module"
: ""

, "Purchase Invoice Module"
: ""

, "Arial"
: ""

, "without customer"
: ""

, "Interval"
: ""

, "begin"
: ""

, "end"
: ""

, "Attributes"
: ""

, "Last Autobill"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Edit Attributes"
: ""

, "Attribute"
: ""

, "Value"
: ""

, "Add a New Value..."
: ""

, "Cancel"
: ""

, "OK"
: ""

, "Bill Contract"
: ""

, "Billing Contract..."
: ""

, "Bill Contract \"{0} - {1}\""
: ""

, "Select the date to generate the bill for"
: ""

, "Either postalcode or postbox is required!"
: ""

, "Copy Supplier"
: ""

, "Add New Supplier"
: ""

, "Edit Supplier \"{0}\""
: ""

, "Copy address to the clipboard"
: ""

, "Core Data"
: ""

, "Accounting"
: ""

, "IBAN"
: ""

, "BIC"
: ""

, "Postal Address"
: ""

, "Miscellaneous"
: ""

, "Enter description"
: ""

, "Copy Purchase Invoice"
: ""

, "Add New Purchase Invoice"
: ""

, "Edit Purchase Invoice \"{0}\""
: ""

, "Due date"
: ""

, "Sales Tax (percent)"
: ""

, "automatically set..."
: ""

, "Overdue date"
: ""

, "Dun date"
: ""

, "Method of payment"
: ""

, "without order confirmation"
: ""

, "Add New Offer"
: ""

, "Select supplier"
: ""

, "total"
: ""

, "inclusive"
: ""

, "exceeding"
: ""

, "Create timesheet"
: ""

, "Create Reversal Invoice"
: ""

, "Copy Invoice"
: ""

, "Add New Invoice"
: ""

, "Edit Invoice \"{0}\""
: ""

, "Positions ({0})"
: ""

, "No customer assigned"
: ""

, "The selected contract doesn't have a customer assigned, yet. Add a customer to the contract with the contract edit dialog."
: ""

, "No cost center assigned"
: ""

, "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
: ""

, "Generic"
: ""

, "Discount"
: ""

, "Total"
: ""

, "Select customer"
: ""

, "Add New Order Confirmation"
: ""

, "without supplier"
: ""

, "Delivery Address"
: ""

, "Rebilling Invoice..."
: ""

, "Rebill Invoice"
: ""

, "Merge Invoices"
: ""

, "Select invoice"
: ""

, "Selected  {0}"
: ""

, "Set as accountable"
: ""

, "Choose product for accountable"
: ""

, "Please use a decimal number here!"
: ""

, "Enter description..."
: ""

, "Export Records from these Positions"
: ""

, "Clipboard"
: ""

, "Print Paper Slip"
: ""

, "Creating {type} Paper Slip"
: ""

, "There where Errors:"
: ""

, "Cannot create { type } paper slip: ({e.code}) { e.message }"
: ""

, "Trac Document { title }"
: ""

, "Expand Positions"
: ""

, "Track Document"
: ""

, "Reversals"
: ""

, "Create { targetRecordName }"
: ""

, "Creating { targetRecordsName }"
: ""

, "Book unbooked { sourceRecordsName }"
: ""

, "Creating followup { targetRecordsName } is allowed for booked { sourceRecordsName } only. Book selected { sourceTypes } now?"
: ""

, "Cannot book { sourceDocument }: ({e.code}) { e.message }"
: ""

, "Cannot create { targetType } from { sourceDocument }: ({e.code}) { e.message }"
: ""

, "Documents Created:"
: ""

, "Confirm Status Change"
: ""

, "Changing this workflow status might not be revertible. Proceed anyway?"
: ""

, "More Boilerplates"
: ""

, "Choose Boilerplate"
: ""

, "Please choose which boilerplate you want to use as { name }"
: ""

, "Existing:"
: ""

, "Applicable:"
: ""

, "Apply postal address"
: ""

, "Either street or postbox is required!"
: ""

, "Copy Customer"
: ""

, "Add New Customer"
: ""

, "Edit Customer \"{0}\""
: ""

, "Ok"
: ""

, "without approver"
: ""

, "without contract"
: ""

, "Boilerplate"
: ""

, "Customer"
: ""

, "Supplier"
: ""

, "Contract"
: ""

, "Offer"
: ""

, "Order Confirmation"
: ""

, "Position"
: ""

, "Product"
: ""

, "Invoice"
: ""

, "Address"
: ""

, "Subproduct"
: ""

, "Purchase Invoice"
: ""

, "Order"
: ""

, "Document"
: ""

, "Delivery"
: ""

, "Invoice Position"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
